View source: R/calc_eval_params.R
| calc_eval_params | R Documentation |
This function calculates and adds several evaluation parameters as additional columns to the mfd data table.
These parameters are essential for evaluating the molecular structure and isotopic distribution, enabling further analysis.
For a detailed description of the output table, see help(mf_data_demo).
calc_eval_params(mfd, verbose = FALSE, ...)
mfd |
data.table with molecular formula data as derived from
|
verbose |
logical; if |
... |
Additional arguments passed to methods. |
The original data.table mfd with additional evaluation columns:
nmNominal molecular mass: Calculated if not already present.
dbe)Double Bond Equivalent (measure of unsaturation).
kmdKendrick mass defect for CH4 versus O exchange.
O/C, H/C, N/C, S/C)Element ratios for a molecular formula.
nsp_type, snp_checkTypes of combinations of N, S, and P atoms in a formula.
nosc``}{Weighted average nominal oxidation state of carbon.} \item{delG0_Cox}{Weighted average Gibbs free energy (Cox) in kJ/mol.} \item{ai}{Aromaticity index.} \item{ppm_filt'A mass accuracy threshold calculated for each spectrum.
Boris P. Koch
Hughey C.A., Hendrickson C.L., Rodgers R.P., Marshall A.G., Qian K.N. (2001). Kendrick mass defect spectrum: A compact visual analysis for ultrahigh-resolution broadband mass spectra. Analytical Chemistry, 73, 4676-4681. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1021/ac010560w")}
Koch B.P., Dittmar T. (2006). From mass to structure: an aromaticity index for high-resolution mass data of natural organic matter. Rapid Communications in Mass Spectrometry, 20, 926-932. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1002/rcm.2386")}
LaRowe D.E., Van Cappellen P. (2011). Degradation of natural organic matter: A thermodynamic analysis. Geochimica et Cosmochimica Acta, 75, 2030-2042. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.gca.2011.01.020")}
Other Formula assignment:
add_known_mf(),
check_formula_library(),
eval_isotopes(),
ume_assign_formulas()
Other calculations:
calc_data_summary(),
calc_dbe(),
calc_exact_mass(),
calc_ideg(),
calc_ma(),
calc_neutral_mass(),
calc_nm(),
calc_norm_int(),
calc_number_assignment(),
calc_number_occurrence(),
calc_recalibrate_ms()
# Example usage with a demo molecular formula dataset
mfd_with_params <- calc_eval_params(mfd = mf_data_demo, verbose = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.