calc_number_occurrence: Calculate number of molecular formulas that were assigned to...

View source: R/calc_number_occurrence.R

calc_number_occurrenceR Documentation

Calculate number of molecular formulas that were assigned to a molecular mass.

Description

Calculates the number of molecular formula (mf) assignments for each individual peak (peak_id) in a given mass spectrum (ms_id).

Usage

calc_number_occurrence(mfd, ...)

Arguments

mfd

data.table with molecular formula data as derived from ume::assign_formulas. Column names of elements/isotopes must match names in the isotope column of ume::masses; values are integers representing counts per formula.

...

Additional arguments passed to methods.

Value

data.table; an additional column "n_occurrence" is added to the original table mfd

See Also

Other calculations: calc_data_summary(), calc_dbe(), calc_eval_params(), calc_exact_mass(), calc_ideg(), calc_ma(), calc_neutral_mass(), calc_nm(), calc_norm_int(), calc_number_assignment(), calc_recalibrate_ms()


ume documentation built on Dec. 13, 2025, 1:06 a.m.