Learn R Programming

ume (version 1.5.2)

extract_aquisition_params_from_folder: Extract Acquisition Parameters from All PDF Files in a Folder

Description

This function processes all PDF files in a specified folder, extracting acquisition parameters from each Bruker PDF report and returns them as a combined data.table.

Usage

extract_aquisition_params_from_folder(folder_path = NULL)

Value

A data.table containing the acquisition parameters for all PDF files.

Arguments

folder_path

Character. Path to the folder containing the PDF files.

See Also

Other internal functions: create_custom_formula_library(), extract_aquisition_params(), extract_metadata_from_ufz_files(), read_xml_peaklist()