filter_mass_accuracy: Automated filter for mass accuracy

View source: R/filter.R

filter_mass_accuracyR Documentation

Automated filter for mass accuracy

Description

This function automatically sets a filter for mass accuracy for each individual spectrum.

Usage

filter_mass_accuracy(
  mfd,
  ma_col = "ppm",
  file_col = "file_id",
  msg = FALSE,
  ...
)

Arguments

mfd

data.table with molecular formula data as derived from ume::assign_formulas. Column names of elements/isotopes must match names in the isotope column of ume::masses; values are integers representing counts per formula.

ma_col

Name of the column that contains mass accuracy values in ppm (string)

file_col

Name of the column that contains file name

msg

logical. Deprecated synonym for verbose.

...

Additional arguments passed to methods.

Value

data.table; subset of original molecular formula table

See Also

Other Formula subsetting: filter_int(), filter_mf_data(), remove_blanks(), subset_known_mf(), ume_assign_formulas(), ume_filter_formulas()


ume documentation built on Dec. 13, 2025, 1:06 a.m.