| filter_mf_data | R Documentation |
This function filters molecular formulas by isotope numbers, element ratios, etc.
filter_mf_data(
mfd,
c_iso_check = FALSE,
n_iso_check = FALSE,
s_iso_check = FALSE,
ma_dev = 3,
dbe_max = 999,
dbe_o_min = -999,
dbe_o_max = 999,
mz_min = 1,
mz_max = 9999,
n_min = 0,
n_max = 999,
s_min = 0,
s_max = 999,
p_min = 0,
p_max = 999,
oc_min = 0,
oc_max = 999,
hc_min = 0,
hc_max = 999,
nc_min = 0,
nc_max = 99,
verbose = FALSE,
...
)
mfd |
data.table with molecular formula data as derived from
|
c_iso_check |
(TRUE / FALSE); check if formulas are verified by the presence of the main daughter isotope |
n_iso_check |
(TRUE / FALSE); check if formulas are verified by the presence of the main daughter isotope |
s_iso_check |
(TRUE / FALSE); check if formulas are verified by the presence of the main daughter isotope |
ma_dev |
Deviation range of mass accuracy in +/- ppm (default: 3 ppm) |
dbe_max |
Maximum number for DBE |
dbe_o_min |
Minimum number for DBE minus O atoms |
dbe_o_max |
Maximum number for DBE minus O atoms |
mz_min |
Minimum of mass to charge value |
mz_max |
Maximum of mass to charge value |
n_min |
Minimum number of nitrogen atoms |
n_max |
Maximum number of nitrogen atoms |
s_min |
Minimum number of nitrogen atoms |
s_max |
Maximum number of nitrogen atoms |
p_min |
Minimum number of nitrogen atoms |
p_max |
Maximum number of nitrogen atoms |
oc_min |
Minimum atomic ratio of oxygen / carbon |
oc_max |
Maximum atomic ratio of oxygen / carbon |
hc_min |
Minimum atomic ratio of hydrogen / carbon |
hc_max |
Maximum atomic ratio of hydrogen / carbon |
nc_min |
Minimum atomic ratio of nitrogen / carbon |
nc_max |
Maximum atomic ratio of nitrogen / carbon |
verbose |
logical; if |
... |
Additional arguments passed to methods. |
data.table; subset of original molecular formula table
Boris P. Koch
Other Formula subsetting:
filter_int(),
filter_mass_accuracy(),
remove_blanks(),
subset_known_mf(),
ume_assign_formulas(),
ume_filter_formulas()
filter_mf_data(mfd = mf_data_demo, dbe_o_max = 10)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.