| known_mf | R Documentation |
Known formulas; contains formulas for which additional knowledge is available. This can be also calibration lists. Due to size reasons the table is restricted to what is covered by standard UME formula library (mz<=700, elements CHONSP considered). The original version is part of the UME database and transferred to UME using UTF-8 encoding. CRAM molecular formulas are taken from the supplementary material that is provided by Hertkorn et al. (2006).
known_mf
A data.table with ~300,000 rows and 14 variables:
Mass to charge ratio (numeric)
molecular formula
taken from www.awi.de
Other ume data:
lib_demo,
masses,
mf_data_demo,
nice_labels_dt,
peaklist_demo,
tab_ume_labels
data(known_mf)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.