| main_docu | R Documentation |
Central place to document arguments (e.g., msg, pl, formula_library) that are
inherited by multiple functions via @inheritParams main_docu. This is not a user-facing
function and is only provided for documentation reuse.
formula_library |
Molecular formula library: a predefined data.table used for
assigning molecular formulas to a peak list and for mass calibration. The library
requires a fixed format, including mass values for matching. Predefined libraries
are available in the R package ume.formulas and further described in
Leefmann et al. (2019). A standard library for marine dissolved organic matter is
|
grp |
Character vector. Names of columns (e.g., sample or file identifiers) used to aggregate results. |
i_magnitude |
String. Name of the column that contains peak intensity information
(default: |
known_mf |
data.table with known molecular formulas ( |
masses |
A data.table. Defaults to |
mf |
Character vector of molecular formula(s)
(e.g., |
mfd |
data.table with molecular formula data as derived from
|
msg |
logical. Deprecated synonym for |
verbose |
logical; if |
mz |
String. Name of the column that contains mass-to-charge information
(default: |
pl |
data.table containing peak data. Mandatory columns include neutral
molecular mass ( |
logo |
Logical. If TRUE, adds a UME caption. |
palname |
Color palette name for f_colorz() (viridis, magma, plasma, etc.). |
nice_labels |
Logical. If true (default) axis/legend labels are generated from ume::nice_labels_dt. |
col_bar |
Logical. If |
plotly |
Logical. If TRUE, return interactive plotly object. |
int_col |
Character. The name of the column that contains the intensity values to be used (e.g. for clustering or color coding). Default usually is "norm_int" for normalized intensity values. |
tf |
Logical. If |
size_dots |
Numeric. Size of the dots in the plot (default = 0.5). |
gg_size |
Base text size for |
cex.axis |
Numeric. Size of axis text (default is |
cex.lab |
Numeric. Size of axis labels (default is |
z_var |
Character. Column name for variable used for color-coding. Content of column should be numeric. |
... |
Additional arguments passed to methods. |
Use @inheritParams main_docu in other functions to pull in these definitions.
This topic is marked internal so it does not clutter the index.
This package is released under the MIT License. See the LICENSE file for details.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.