masses: Masses: Elements and isotopes

massesR Documentation

Masses: Elements and isotopes

Description

Contains masses, valences, isotopes and isotope ratios of elements based on data by NIST Physical Measurement Laboratory (https://www.nist.gov/pml).

Usage

masses

Format

A data.table having 288 rows and 23 variables:

element

Element symbol in lower case

symbol

Element symbol in upper case

isotope

Isotope symbol in lower case

label

Isotope symbol in upper case

nm

Nominal mass of the isotope

exact_mass

Exact mass of the isotope

mole_fraction

Mole fraction compared to all isotopes of an element

relative_abundance

Relative abundance compared to the main (most abundant) isotope

valence

Valence at standard conditions

valence2

Alternative valence at standard conditions

hill_order

Rank in Hill Order for molecular formulas (cf. https://en.wikipedia.org/wiki/Chemical_formula)

https://www.nist.gov/pml/atomic-weights-and-isotopic-compositions-relative-atomic-masses

See Also

Other ume data: known_mf, lib_demo, mf_data_demo, nice_labels_dt, peaklist_demo, tab_ume_labels

Examples

data(masses)

ume documentation built on Dec. 13, 2025, 1:06 a.m.