nice_labels_dt: nice_labels_dt

nice_labels_dtR Documentation

nice_labels_dt

Description

nice_labels_dt

Usage

nice_labels_dt

Format

A data.table with labels that can be used for plots

name_substitute

Name that will be displayed instead of the standard column name

name_pattern

Name of the standard column in ume tables

taken from www.awi.de

See Also

Other ume data: known_mf, lib_demo, masses, mf_data_demo, peaklist_demo, tab_ume_labels

Examples

data(nice_labels_dt)

ume documentation built on Dec. 13, 2025, 1:06 a.m.