| peaklist_demo | R Documentation |
Contains parts of the peaklist (200 - 300 m/z) from mass spectra to use as demonstration and validation dataset. The sample mass spectra contain one blank, three replicates of North Sea water, and three Arctic fjord samples as triplicates.
peaklist_demo
A data.table having 31,091 rows and 7 variables:
A unique identifier for a mass spectrum (integer)
A unique label for a mass spectrum or sample (character)
A unique identifier for a peak in the entire peak list (integer)
Mass to charge ratio of the singly charged molecular ion (numeric)
Peak magnitude of the molecular ion (numeric)
Signal to noise ratio of the molecular ion (numeric)
Mass resolution of the peak / ion (numeric)
taken from www.awi.de
Other ume data:
known_mf,
lib_demo,
masses,
mf_data_demo,
nice_labels_dt,
tab_ume_labels
data(peaklist_demo)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.