| remove_unknown_columns | R Documentation |
This function removes columns that exclusively contain the value defined in 'search_term' (such as " unknown" (default)).
remove_unknown_columns(df, excl_cols = NULL, search_term = " unknown", ...)
df |
data.table that contains empty columns |
excl_cols |
List of column names that should not be removed, even if all values contain search_term |
search_term |
String that uniquely occurs in one column |
... |
Additional arguments passed to methods. |
Other Clean data output:
remove_id_columns()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.