View source: R/ume_utilities.R
| ume_assign_formulas | R Documentation |
Assigns molecular formulas to neutral molecular masses and calculates all parameters required for data evaluation, such as a posteriori filtering of molecular formulas, plotting, and statistics. The function uses a pre-build molecular formula library.
ume_assign_formulas(pl, formula_library, verbose = FALSE, ...)
pl |
data.table containing peak data. Mandatory columns include neutral
molecular mass ( |
formula_library |
Molecular formula library: a predefined data.table used for
assigning molecular formulas to a peak list and for mass calibration. The library
requires a fixed format, including mass values for matching. Predefined libraries
are available in the R package ume.formulas and further described in
Leefmann et al. (2019). A standard library for marine dissolved organic matter is
|
verbose |
logical; if |
... |
Arguments passed on to
|
All function arguments: args(filter_mf_data) args(filter_int)
A data.table having molecular formula assignments for each mass.
Other Formula assignment:
add_known_mf(),
calc_eval_params(),
check_formula_library(),
eval_isotopes()
Other Formula subsetting:
filter_int(),
filter_mass_accuracy(),
filter_mf_data(),
remove_blanks(),
subset_known_mf(),
ume_filter_formulas()
Other ume wrapper:
ume_filter_formulas()
ume_assign_formulas(pl = peaklist_demo, formula_library = lib_demo, pol = "neg", ma_dev = 0.2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.