uplot_dbe_minus_o_freq: Frequency Plot of DBE - O

View source: R/uplot_dbe_minus_o_freq.R

uplot_dbe_minus_o_freqR Documentation

Frequency Plot of DBE - O

Description

Creates a bar plot showing the frequency distribution of dbe_o (DBE minus oxygen). The plot uses the unified UME plotting theme and optionally adds a small UME caption. A Plotly version can be returned.

Usage

uplot_dbe_minus_o_freq(df, gg_size = 12, logo = TRUE, plotly = FALSE, ...)

Arguments

df

A data.table containing at least the column dbe_o.

gg_size

Base text size for theme_uplots(). Default = 12.

Logical. If TRUE, adds a UME caption.

plotly

Logical. If TRUE, return interactive plotly object.

...

Additional arguments passed to methods.

Value

A ggplot2 object or, if requested, a Plotly object.

See Also

Other plots: uplot_cluster(), uplot_cvm(), uplot_dbe_vs_c(), uplot_freq_ma(), uplot_freq_vs_ppm(), uplot_hc_vs_m(), uplot_heteroatoms(), uplot_isotope_precision(), uplot_kmd(), uplot_lcms(), uplot_ma_vs_mz(), uplot_ms(), uplot_n_mf_per_sample(), uplot_pca(), uplot_ratios(), uplot_reproducibility(), uplot_ri_vs_sample(), uplot_vk()

Examples

uplot_dbe_minus_o_freq(mf_data_demo)


ume documentation built on Dec. 13, 2025, 1:06 a.m.