View source: R/uplot_dbe_vs_o.R
| uplot_dbe_vs_o | R Documentation |
This function generates a scatter plot of Double Bond Equivalent (DBE) versus the number of oxygen atoms (o).
It allows for optional customization of colors based on a specified variable (z_var) and offers the
option to convert the plot to an interactive plotly object.
uplot_dbe_vs_o(
df,
z_var = "norm_int",
palname = "redblue",
col_bar = TRUE,
tf = FALSE,
logo = TRUE,
cex.axis = 12,
cex.lab = 15,
plotly = FALSE,
...
)
df |
A data frame containing the data. The columns |
z_var |
Character. Column name for variable used for color-coding. Content of column should be numeric. |
palname |
Color palette name for f_colorz() (viridis, magma, plasma, etc.). |
col_bar |
Logical. If |
tf |
Logical. If |
logo |
Logical. If TRUE, adds a UME caption. |
cex.axis |
Numeric. Size of axis text (default is |
cex.lab |
Numeric. Size of axis labels (default is |
plotly |
Logical. If TRUE, return interactive plotly object. |
... |
Arguments passed on to
|
A ggplot object or a plotly object depending on the plotly argument.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.