View source: R/uplot_dbe_vs_ppm.R
| uplot_dbe_vs_ppm | R Documentation |
This function generates a scatter plot of DBE (Double Bond Equivalent) versus parts per million (ppm) from the provided data.
It also provides the option to customize the appearance and to return an interactive plotly plot.
uplot_dbe_vs_ppm(
df,
size_dots = 0.5,
cex.axis = 1,
cex.lab = 1.4,
plotly = FALSE,
...
)
df |
A data frame containing the data. The columns |
size_dots |
Numeric. Size of the dots in the plot (default = 0.5). |
cex.axis |
Numeric. Size of axis text (default is |
cex.lab |
Numeric. Size of axis labels (default is |
plotly |
Logical. If TRUE, return interactive plotly object. |
... |
Additional arguments passed to methods. |
A ggplot object or a plotly object depending on the plotly argument.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.