uplot_isotope_precision: Precision of Isotope Abundance

View source: R/uplot_isotope_precision.R

uplot_isotope_precisionR Documentation

Precision of Isotope Abundance

Description

Visualizes the deviation between measured and theoretical 13C isotope ratios. Supports optional data reduction (binning) to greatly enhance interactive rendering speed in Plotly.

Usage

uplot_isotope_precision(
  mfd,
  z_var = "nsp_tot",
  int_col = "norm_int",
  size_dots = 1.5,
  bins = 100,
  data_reduction = FALSE,
  tf = FALSE,
  logo = TRUE,
  plotly = FALSE,
  cex.axis = 1,
  cex.lab = 1.4
)

Arguments

mfd

data.table with molecular formula data as derived from ume::assign_formulas. Column names of elements/isotopes must match names in the isotope column of ume::masses; values are integers representing counts per formula.

z_var

Column used for color mapping (default: "nsp_tot")

int_col

Intensity column (default: "norm_int")

size_dots

Numeric. Size of the dots in the plot (default = 0.5).

bins

Number of bins used when data_reduction = TRUE

data_reduction

Logical. If TRUE, bins the data and uses bin medians (recommended for very large datasets; speeds up rendering massively).

tf

Logical. If TRUE, applies a transformation to the color scale (default is FALSE).

Logical. If TRUE, adds a UME caption.

plotly

Logical. Return a plotly object instead of ggplot.

cex.axis

Numeric. Size of axis text (default is 1).

cex.lab

Numeric. Size of axis labels (default is 1.4).

Value

A ggplot or plotly object.

See Also

Other plots: uplot_cluster(), uplot_cvm(), uplot_dbe_minus_o_freq(), uplot_dbe_vs_c(), uplot_freq_ma(), uplot_freq_vs_ppm(), uplot_hc_vs_m(), uplot_heteroatoms(), uplot_kmd(), uplot_lcms(), uplot_ma_vs_mz(), uplot_ms(), uplot_n_mf_per_sample(), uplot_pca(), uplot_ratios(), uplot_reproducibility(), uplot_ri_vs_sample(), uplot_vk()


ume documentation built on Dec. 13, 2025, 1:06 a.m.