uplot_n_mf_per_sample: Number of Molecular Formulas per Sample Plot

View source: R/uplot_n_mf_per_sample.R

uplot_n_mf_per_sampleR Documentation

Number of Molecular Formulas per Sample Plot

Description

Creates a bar plot showing how many molecular formulas were assigned per sample (file_id). The plot title contains the mean and standard deviation of assigned molecular formulas across samples. Optionally, the plot can be converted to an interactive Plotly plot or display the UltraMassExplorer logo.

Usage

uplot_n_mf_per_sample(
  df,
  col = "grey",
  logo = TRUE,
  width = 0.3,
  gg_size = 12,
  plotly = FALSE
)

Arguments

df

A data.table containing at least a file_id column.

col

Character. Fill color for the bars (default "grey").

Logical. If TRUE, adds a UME caption.

width

Numeric. Width of bars (default 0.3).

gg_size

Base text size for theme_uplots(). Default = 12.

plotly

Logical. If TRUE, return interactive plotly object.

Details

Number of Molecular Formulas per Sample / File

Value

A ggplot object, or a plotly object if plotly = TRUE.

See Also

Other plots: uplot_cluster(), uplot_cvm(), uplot_dbe_minus_o_freq(), uplot_dbe_vs_c(), uplot_freq_ma(), uplot_freq_vs_ppm(), uplot_hc_vs_m(), uplot_heteroatoms(), uplot_isotope_precision(), uplot_kmd(), uplot_lcms(), uplot_ma_vs_mz(), uplot_ms(), uplot_pca(), uplot_ratios(), uplot_reproducibility(), uplot_ri_vs_sample(), uplot_vk()

Examples

uplot_n_mf_per_sample(mf_data_demo)


ume documentation built on Dec. 13, 2025, 1:06 a.m.