View source: R/uplot_ppm_avg.R
| uplot_ppm_avg | R Documentation |
This function generates a bar plot showing the median of mass accuracy (ppm) for each sample.
It also provides the option to convert the plot into an interactive plotly object.
uplot_ppm_avg(df, cex.axis = 12, cex.lab = 15, plotly = FALSE, ...)
df |
A data frame containing the data. The columns |
cex.axis |
Numeric. Size of axis text (default is |
cex.lab |
Numeric. Size of axis labels (default is |
plotly |
Logical. If TRUE, return interactive plotly object. |
... |
Additional arguments passed to methods. |
A ggplot object or a plotly object depending on the plotly argument.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.