View source: R/uplot_reproducibility.R
| uplot_reproducibility | R Documentation |
Computes reproducibility of sample analyses based on the relative intensity
column (norm_int). For each molecular formula (mf), the function calculates:
number of occurrences (N)
median relative intensity (ri)
relative standard deviation (RSD = sd/median × 100)
It also bins ri into integer bins and calculates the median RSD per bin.
The function returns:
processed tables
two ggplot2 objects:
intensity vs RSD scatter plot
binned median RSD plot
uplot_reproducibility(df, ri = "norm_int")
df |
A data.table or data.frame containing at least columns |
ri |
Character string: name of the intensity column. Default: |
A list containing:
tmpSummary table by molecular formula
tmp2Binned median RSD table
plot_rsdScatter plot of RI vs RSD (ggplot2)
plot_binsMedian RSD per bin (ggplot2)
Other plots:
uplot_cluster(),
uplot_cvm(),
uplot_dbe_minus_o_freq(),
uplot_dbe_vs_c(),
uplot_freq_ma(),
uplot_freq_vs_ppm(),
uplot_hc_vs_m(),
uplot_heteroatoms(),
uplot_isotope_precision(),
uplot_kmd(),
uplot_lcms(),
uplot_ma_vs_mz(),
uplot_ms(),
uplot_n_mf_per_sample(),
uplot_pca(),
uplot_ratios(),
uplot_ri_vs_sample(),
uplot_vk()
out <- uplot_reproducibility(mf_data_demo, ri = "norm_int")
out$plot_rsd
out$plot_bins
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.