View source: R/uplot_ri_vs_sample.R
| uplot_ri_vs_sample | R Documentation |
Creates a bar plot showing the median relative intensity (default: norm_int)
for each sample (grouped by file_id).
The overall dataset-wide median and standard deviation are shown in the title.
uplot_ri_vs_sample(
df,
int_col = "norm_int",
grp = "file_id",
col = "grey",
logo = TRUE,
width = 0.3,
gg_size = 12
)
df |
A data.table containing at least:
|
int_col |
Character. Column name containing relative intensity values. |
grp |
Character. Column name specifying sample / file grouping. |
col |
Character. Fill color for bars. |
logo |
Logical. If TRUE, adds a UME caption. |
width |
Numeric. Width of bars (default |
gg_size |
Base text size for |
Plot Average Relative Intensity per Sample
A ggplot2 object containing a bar plot of per-sample median relative intensity.
Other plots:
uplot_cluster(),
uplot_cvm(),
uplot_dbe_minus_o_freq(),
uplot_dbe_vs_c(),
uplot_freq_ma(),
uplot_freq_vs_ppm(),
uplot_hc_vs_m(),
uplot_heteroatoms(),
uplot_isotope_precision(),
uplot_kmd(),
uplot_lcms(),
uplot_ma_vs_mz(),
uplot_ms(),
uplot_n_mf_per_sample(),
uplot_pca(),
uplot_ratios(),
uplot_reproducibility(),
uplot_vk()
uplot_ri_vs_sample(mf_data_demo, int_col = "norm_int", grp = "file")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.