Join molecular formula data and metadata about known formulas (e.g. annotate carboxylic-rich alicyclic molecules (CRAM)). The name of the molecular formula column will be set to "mf".
add_known_mf(mfd, mf_col = "mf", known_mf = ume::known_mf, ...)A data.table containing additional columns having information on formula categories
data.table with molecular formula data as derived from
ume::assign_formulas. Column names of elements/isotopes must match names in
the isotope column of ume::masses; values are integers representing
counts per formula.
Name of the column in mfd that has the molecular formula information (default: "mf"). Formulas have upper case element symbols and elements in the formula are ordered according to the Hill system.
data.table with known molecular formulas (ume::known_mf).
Additional arguments passed to methods.
Boris P. Koch
CRAM Hertkorn N., Benner R., Frommberger M., Schmitt-Kopplin P., Witt M., Kaiser K., Kettrup A., Hedges J.I. (2006). Characterization of a major refractory component of marine dissolved organic matter. Geochimica et Cosmochimica Acta, 70, 2990-3010. tools:::Rd_expr_doi("10.1016/j.gca.2006.03.021") Surfactants Lechtenfeld O.J., Koch B.P., Gasparovic B., Frka S., Witt M., Kattner G. (2013). The influence of salinity on the molecular and optical properties of surface microlayers in a karstic estuary. Marine Chemistry, 150, 25-38. tools:::Rd_expr_doi("10.1016/j.marchem.2013.01.006")
Ideg Flerus R., Lechtenfeld O.J., Koch B.P., McCallister S.L., Schmitt-Kopplin P., Benner R., Kaiser K., Kattner G. (2012). A molecular perspective on the ageing of marine dissolved organic matter. Biogeosciences, 9, 1935-1955. tools:::Rd_expr_doi("10.5194/bg-9-1935-2012")
iTerr Medeiros P.M., Seidel M., Niggemann J., Spencer R.G.M., Hernes P.J., Yager P.L., Miller W.L., Dittmar T., Hansell D.A. (2016). A novel molecular approach for tracing terrigenous dissolved organic matter into the deep ocean. Global Biogeochemical Cycles, 30, 689-699. tools:::Rd_expr_doi("10.1002/2015gb005320")
Other Formula assignment:
calc_eval_params(),
check_formula_library(),
eval_isotopes(),
ume_assign_formulas()
add_known_mf(mfd = mf_data_demo)
Run the code above in your browser using DataLab