View source: R/calc_exact_mass.R
| calc_exact_mass | R Documentation |
This function calculates the exact monoisotopic mass for each molecule
in a given data table based on the specified isotope composition. Exact masses of
elements and isotopes used in the calculation are retrieved from the ume::masses data,
based on data from NIST (https://www.nist.gov/pml/atomic-weights-and-isotopic-compositions-relative-atomic-masses).
calc_exact_mass(mfd, ...)
mfd |
data.table with molecular formula data as derived from
|
... |
Additional arguments passed to methods. |
A numeric vector of the calculated exact monoisotopic mass.
Boris P. Koch
Other calculations:
calc_data_summary(),
calc_dbe(),
calc_eval_params(),
calc_ideg(),
calc_ma(),
calc_neutral_mass(),
calc_nm(),
calc_norm_int(),
calc_number_assignment(),
calc_number_occurrence(),
calc_recalibrate_ms()
# Example with demo data
calc_exact_mass(mfd = mf_data_demo)
# Custom example
calc_exact_mass(data.table::data.table(c = 3, h = 8, o = 1))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.