calc_exact_mass: Calculate Exact Monoisotopic Mass of a Molecule
Description
This function calculates the exact monoisotopic mass for each molecule
in a given data table based on the specified isotope composition. Exact masses of
elements and isotopes used in the calculation are retrieved from the ume::masses data,
based on data from NIST (https://www.nist.gov/pml/atomic-weights-and-isotopic-compositions-relative-atomic-masses).
Usage
calc_exact_mass(mfd, ...)
Value
A numeric vector of the calculated exact monoisotopic mass.
Arguments
mfd
data.table with molecular formula data as derived from
ume::assign_formulas. Column names of elements/isotopes must match names in
the isotope column of ume::masses; values are integers representing
counts per formula.