| download_library | R Documentation |
Downloads one of the UME formula libraries from Zenodo only when explicitly called by the user.
Unlike earlier versions, this CRAN-compliant implementation:
never writes to the user's filespace unless dest is explicitly provided
does NOT create ~/.ume/ or any other default directory
does NOT perform automatic caching
In non-interactive environments (CRAN checks), the function returns NULL
download_library(
library = "lib_05.rds",
doi = "10.5281/zenodo.17606457",
dest = NULL,
overwrite = FALSE
)
library |
Character. One of |
doi |
Character. Zenodo DOI. |
dest |
Optional file path where the library should be saved.
If |
overwrite |
Logical. Redownload even if |
A data.table or NULL (in non-interactive mode).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.