View source: R/eval_isotopes.R
| eval_isotopes | R Documentation |
Add isotope information to the parent mass and optionally remove isotopoloques from mfd table. Required for further data evaluation that considers isotope information.
eval_isotopes(mfd, remove_isotopes = TRUE, verbose = FALSE, ...)
mfd |
data.table with molecular formula data as derived from
|
remove_isotopes |
If set to TRUE (default), all entries for isotopologues are removed from mfd. The main isotope information for each parent ion is still maintained in the "intxy"-columns. |
verbose |
logical; if |
... |
Additional arguments passed to methods. |
A data.table with additional columns such as "int_13c" containing stable isotope abundance information.
Boris P. Koch
Other Formula assignment:
add_known_mf(),
calc_eval_params(),
check_formula_library(),
ume_assign_formulas()
eval_isotopes(mfd = mf_data_demo)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.