| filter_mass_accuracy | R Documentation |
This function automatically sets a filter for mass accuracy for each individual spectrum.
filter_mass_accuracy(
mfd,
ma_col = "ppm",
file_col = "file_id",
msg = FALSE,
...
)
mfd |
data.table with molecular formula data as derived from
|
ma_col |
Name of the column that contains mass accuracy values in ppm (string) |
file_col |
Name of the column that contains file name |
msg |
logical. Deprecated synonym for |
... |
Additional arguments passed to methods. |
data.table; subset of original molecular formula table
Other Formula subsetting:
filter_int(),
filter_mf_data(),
remove_blanks(),
subset_known_mf(),
ume_assign_formulas(),
ume_filter_formulas()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.