View source: R/get_isotope_info.R
| get_isotope_info | R Documentation |
Checks if element/isotope columns are present in mfd
and lookup of NIST isotope information (based on masses).
Can be applied to a formula library and any table having molecular formula data.
If only an element name is identified, the symbol and data of the lightest isotope
of the element will be returned.
For example, the column name "C" will return "12C" isotope data.
get_isotope_info(mfd, masses = ume::masses, verbose = FALSE, ...)
mfd |
data.table with molecular formula data as derived from
|
masses |
A data.table. Defaults to |
verbose |
logical; if |
... |
Additional arguments passed to methods. |
A data.table containing information on all isotopes identified in mfd
and a column "orig_name" having the original names of the
isotope / element columns in mfd. Results are ordered according to Hill system.
get_isotope_info(mfd = mf_data_demo, verbose = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.