Checks if element/isotope columns are present in mfd
and lookup of NIST isotope information (based on masses).
Can be applied to a formula library and any table having molecular formula data.
If only an element name is identified, the symbol and data of the lightest isotope
of the element will be returned.
For example, the column name "C" will return "12C" isotope data.
get_isotope_info(mfd, masses = ume::masses, verbose = FALSE, ...)A data.table containing information on all isotopes identified in mfd
and a column "orig_name" having the original names of the
isotope / element columns in mfd. Results are ordered according to Hill system.
data.table with molecular formula data as derived from
ume::assign_formulas. Column names of elements/isotopes must match names in
the isotope column of ume::masses; values are integers representing
counts per formula.
A data.table. Defaults to ume::masses (based on NIST data)
containing isotope information for elements, including nominal and exact mass,
relative abundance, and Hill system order.
logical; if TRUE, show progress messages.
Additional arguments passed to methods.
get_isotope_info(mfd = mf_data_demo, verbose = TRUE)
Run the code above in your browser using DataLab