Learn R Programming

ume (version 1.5.2)

known_mf: Collection of known formulas, for which additional information is available.

Description

Known formulas; contains formulas for which additional knowledge is available. This can be also calibration lists. Due to size reasons the table is restricted to what is covered by standard UME formula library (mz<=700, elements CHONSP considered). The original version is part of the UME database and transferred to UME using UTF-8 encoding. CRAM molecular formulas are taken from the supplementary material that is provided by Hertkorn et al. (2006).

Usage

known_mf

Arguments

Format

A data.table with ~300,000 rows and 14 variables:

mz

Mass to charge ratio (numeric)

mf

molecular formula

See Also

Other ume data: lib_demo, masses, mf_data_demo, nice_labels_dt, peaklist_demo, tab_ume_labels

Examples

Run this code
data(known_mf)

Run the code above in your browser using DataLab