| masses | R Documentation |
Contains masses, valences, isotopes and isotope ratios of elements based on data by NIST Physical Measurement Laboratory (https://www.nist.gov/pml).
masses
A data.table having 288 rows and 23 variables:
Element symbol in lower case
Element symbol in upper case
Isotope symbol in lower case
Isotope symbol in upper case
Nominal mass of the isotope
Exact mass of the isotope
Mole fraction compared to all isotopes of an element
Relative abundance compared to the main (most abundant) isotope
Valence at standard conditions
Alternative valence at standard conditions
Rank in Hill Order for molecular formulas (cf. https://en.wikipedia.org/wiki/Chemical_formula)
https://www.nist.gov/pml/atomic-weights-and-isotopic-compositions-relative-atomic-masses
Other ume data:
known_mf,
lib_demo,
mf_data_demo,
nice_labels_dt,
peaklist_demo,
tab_ume_labels
data(masses)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.