| nice_labels_dt | R Documentation |
nice_labels_dt
nice_labels_dt
A data.table with labels that can be used for plots
Name that will be displayed instead of the standard column name
Name of the standard column in ume tables
taken from www.awi.de
Other ume data:
known_mf,
lib_demo,
masses,
mf_data_demo,
peaklist_demo,
tab_ume_labels
data(nice_labels_dt)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.