Learn R Programming

ume (version 1.5.2)

nice_labels_dt: nice_labels_dt

Description

nice_labels_dt

Usage

nice_labels_dt

Arguments

Format

A data.table with labels that can be used for plots

name_substitute

Name that will be displayed instead of the standard column name

name_pattern

Name of the standard column in ume tables

See Also

Other ume data: known_mf, lib_demo, masses, mf_data_demo, peaklist_demo, tab_ume_labels

Examples

Run this code
data(nice_labels_dt)

Run the code above in your browser using DataLab