powered by
nice_labels_dt
A data.table with labels that can be used for plots
Name that will be displayed instead of the standard column name
Name of the standard column in ume tables
Other ume data: known_mf, lib_demo, masses, mf_data_demo, peaklist_demo, tab_ume_labels
known_mf
lib_demo
masses
mf_data_demo
peaklist_demo
tab_ume_labels
data(nice_labels_dt)
Run the code above in your browser using DataLab