| order_columns | R Documentation |
Take most prominent columns required for data evaluation first - followed by all other columns.
order_columns(mfd, col_order = NULL, ...)
mfd |
data.table with molecular formula data as derived from
|
col_order |
A list of column names that defines the order of columns of mfd. Default is: cols = c("sample_tag", "sample_id", "file", "file_id", "peak_id", "i_magnitude", "norm_int", "m", "m_cal", "ppm", "nm", "mf", "dbe", "c", "h", "n", "o", "p", "s", "hc", "oc", "nc", "sc", "ai", "z", "kmd") If "cols" is NULL the default order is applied. |
... |
Additional arguments passed to methods. |
A data.table containing isotope data for those isotopes present in mfd.
Other tools:
add_missing_element_columns()
order_columns(mfd = mf_data_demo)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.