Contains parts of the peaklist (200 - 300 m/z) from mass spectra
to use as demonstration and validation dataset.
The sample mass spectra contain one blank, three replicates
of North Sea water, and three Arctic fjord samples as triplicates.
Usage
peaklist_demo
Arguments
Format
A data.table having 31,091 rows and 7 variables:
file_id
A unique identifier for a mass spectrum (integer)
file
A unique label for a mass spectrum or sample (character)
peak_id
A unique identifier for a peak in the entire peak list (integer)
mz
Mass to charge ratio of the singly charged molecular ion (numeric)
i_magnitude
Peak magnitude of the molecular ion (numeric)
s_n
Signal to noise ratio of the molecular ion (numeric)
res
Mass resolution of the peak / ion (numeric)
See Also
Other ume data:
known_mf,
lib_demo,
masses,
mf_data_demo,
nice_labels_dt,
tab_ume_labels