| subset_known_mf | R Documentation |
Subset all molecular formulas that are present in one or more categories of ume::known_mf. Based on presence / absence.
subset_known_mf(
mfd,
select_category = NULL,
exclude_category = NULL,
verbose = FALSE,
...
)
mfd |
data.table with molecular formula data as derived from
|
select_category |
List of category names that should be selected |
exclude_category |
List of category names that should be ignored |
verbose |
logical; if |
... |
Additional arguments passed to methods. |
data.table; subset of original molecular formula data.table (mfd)
Other Formula subsetting:
filter_int(),
filter_mass_accuracy(),
filter_mf_data(),
remove_blanks(),
ume_assign_formulas(),
ume_filter_formulas()
subset_known_mf(category_list = c("marine_dom"), mfd = mf_data_demo, verbose = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.