Learn R Programming

ume (version 1.5.2)

subset_known_mf: Subsetting known molecular formula categories

Description

Subset all molecular formulas that are present in one or more categories of ume::known_mf. Based on presence / absence.

Usage

subset_known_mf(
  mfd,
  select_category = NULL,
  exclude_category = NULL,
  verbose = FALSE,
  ...
)

Value

data.table; subset of original molecular formula data.table (mfd)

Arguments

mfd

data.table with molecular formula data as derived from ume::assign_formulas. Column names of elements/isotopes must match names in the isotope column of ume::masses; values are integers representing counts per formula.

select_category

List of category names that should be selected

exclude_category

List of category names that should be ignored

verbose

logical; if TRUE, show progress messages.

...

Additional arguments passed to methods.

See Also

Other Formula subsetting: filter_int(), filter_mass_accuracy(), filter_mf_data(), remove_blanks(), ume_assign_formulas(), ume_filter_formulas()

Examples

Run this code
subset_known_mf(category_list = c("marine_dom"), mfd = mf_data_demo, verbose = TRUE)

Run the code above in your browser using DataLab