View source: R/uplot_n_mf_per_sample.R
| uplot_n_mf_per_sample | R Documentation |
Creates a bar plot showing how many molecular formulas were assigned per
sample (file_id). The plot title contains the mean and standard deviation
of assigned molecular formulas across samples. Optionally, the plot can be
converted to an interactive Plotly plot or display the UltraMassExplorer logo.
uplot_n_mf_per_sample(
df,
col = "grey",
logo = TRUE,
width = 0.3,
gg_size = 12,
plotly = FALSE
)
df |
A data.table containing at least a |
col |
Character. Fill color for the bars (default |
logo |
Logical. If TRUE, adds a UME caption. |
width |
Numeric. Width of bars (default |
gg_size |
Base text size for |
plotly |
Logical. If TRUE, return interactive plotly object. |
Number of Molecular Formulas per Sample / File
A ggplot object, or a plotly object if plotly = TRUE.
Other plots:
uplot_cluster(),
uplot_cvm(),
uplot_dbe_minus_o_freq(),
uplot_dbe_vs_c(),
uplot_freq_ma(),
uplot_freq_vs_ppm(),
uplot_hc_vs_m(),
uplot_heteroatoms(),
uplot_isotope_precision(),
uplot_kmd(),
uplot_lcms(),
uplot_ma_vs_mz(),
uplot_ms(),
uplot_pca(),
uplot_ratios(),
uplot_reproducibility(),
uplot_ri_vs_sample(),
uplot_vk()
uplot_n_mf_per_sample(mf_data_demo)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.