View source: R/ustats_outlier.R
| ustats_outlier | R Documentation |
This function computes an out_score for each value in a selected column.
The score increases when a value is flagged as an outlier by one or more tests:
IQR test, quantile cutoffs, and Hampel filter.
ustats_outlier(dt, check_col = "ppm", verbose = FALSE, ...)
dt |
A |
check_col |
A character string naming the column to test for outliers. |
verbose |
Logical; print summary statistics when TRUE. |
... |
Additional arguments passed to methods. |
A data.table containing new columns: out_score, out_box,
out_quantile, and out_hampel.
ustats_outlier(mf_data_demo, check_col = "ppm")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.